@@ -1,2 +1,2 @@
 from deephy.deephy import ImageFile, Neuron, Layer, DeephyData
-__all__ = [ImageFile, Neuron, Layer, DeephyData]
+__all__ = ["ImageFile", "Neuron", "Layer", "DeephyData"]
